@@ -2,5 +2,5 @@ from .opposablethumbs import OpposableThumbs
 
 
 def opposablethumb(request):
-    ot = OpposableThumbs(request.META['QUERY_STRING'])
+    ot = OpposableThumbs(request.META["QUERY_STRING"])
     return ot.response()
